<?php
defined('ABSPATH') or die("Please don't run this script.");


get_template_part( 'inc/lib/amp' );


define( 'SIMPLE_DAYS_THEME_DIR', trailingslashit( get_template_directory() ) );
define( 'SIMPLE_DAYS_THEME_URI', trailingslashit( esc_url( get_template_directory_uri() ) ) );

require SIMPLE_DAYS_THEME_DIR . 'inc/template-tags.php';

get_template_part( 'inc/extra','content' );

if ( ! function_exists( 'simple_days_admin_menu' ) ) :
  function simple_days_admin_menu() {
    add_theme_page( esc_html_x( 'Color' , 'dashboard' , 'simple-days'), esc_html_x( 'Color' , 'dashboard' , 'simple-days'), 'manage_options', 'customize.php?autofocus[panel]=simple_days_custom_colors' );
    add_theme_page( 'Simple Days', 'Simple Days', 'manage_options', 'customize.php?autofocus[panel]=simple_days_setting' );
  }
endif;
add_action('admin_menu', 'simple_days_admin_menu');

if ( ! function_exists( 'simple_days_setup' ) ) :
  function simple_days_setup() {
    
    get_template_part( 'inc/lib/setup' );
  }
endif;
add_action( 'after_setup_theme', 'simple_days_setup' );







if ( ! function_exists( 'simple_days_get_the_archive_title' ) ) :
  
  function simple_days_get_the_archive_title($title) {
    if ( is_category() ) {
      $title = single_cat_title( '<i class="fa fa-folder-open-o" aria-hidden="true"></i> ', false );
    }elseif ( is_tag() ) {
      $title = single_tag_title( '<i class="fa fa-tag" aria-hidden="true"></i> ', false );
    } elseif ( is_author() ) {
      $title = '<i class="fa fa-user" aria-hidden="true"></i> '. get_the_author();

    } elseif ( is_year() || is_month() || is_day() ) {
     $title = '<i class="fa fa-calendar-check-o" aria-hidden="true"></i> '. $title;
   }
   return $title;
 }
endif;
add_filter( 'get_the_archive_title', 'simple_days_get_the_archive_title');

if ( ! function_exists( 'simple_days_replace_script_type' ) ) :
  function simple_days_replace_script_type($tag) {
   if (!is_amp){
     $tag =  str_replace("type='text/javascript' src='https://www.googletagmanager.com/gtag/js", "async src='https://www.googletagmanager.com/gtag/js", $tag);
   }else{
     $tag =  preg_replace('/^(?!.*(ampproject)).*$/i', '', $tag);
     $tag =  str_replace("type='text/javascript'", "async", $tag);
     $tag =  str_replace("src='https://cdn.ampproject.org/v0/amp-ad-0.1.js", " custom-element=\"amp-ad\" src='https://cdn.ampproject.org/v0/amp-ad-0.1.js", $tag);
     $tag =  str_replace("src='https://cdn.ampproject.org/v0/amp-form-0.1.js", " custom-element=\"amp-form\" src='https://cdn.ampproject.org/v0/amp-form-0.1.js", $tag);
     $tag =  str_replace("src='https://cdn.ampproject.org/v0/amp-analytics-0.1.js", " custom-element=\"amp-analytics\" src='https://cdn.ampproject.org/v0/amp-analytics-0.1.js", $tag);
     $tag =  str_replace("src='https://cdn.ampproject.org/v0/amp-iframe-0.1.js", " custom-element=\"amp-iframe\" src='https://cdn.ampproject.org/v0/amp-iframe-0.1.js", $tag);
     $tag =  str_replace("src='https://cdn.ampproject.org/v0/amp-facebook-like-0.1.js", " custom-element=\"amp-facebook-like\" src='https://cdn.ampproject.org/v0/amp-facebook-like-0.1.js", $tag);
   }
   return $tag;
 }
endif;
add_filter( 'script_loader_tag','simple_days_replace_script_type');

if ( ! function_exists( 'simple_days_replace_link_stylesheet' ) ) :
  
  function simple_days_replace_link_stylesheet( $tag ) {
   if (is_amp){
     $tag =  preg_replace( array( "/'/", '/(id|type|media)=".+?" */', '/ \/>/' ), array( '"', '', '>' ), $tag );
   }
   return $tag;
 }
endif;
add_filter( 'style_loader_tag', 'simple_days_replace_link_stylesheet' );

if ( ! function_exists( 'simple_days_required_stylesheets' ) ) :
  function simple_days_required_stylesheets(){

    get_template_part( 'inc/lib/required_stylesheets' );

  }
endif;
add_action('wp_enqueue_scripts','simple_days_required_stylesheets');



if ( ! function_exists( 'simple_days_footer_stylesheets' ) ) :
  function simple_days_footer_stylesheets() {

    if (!is_amp){
      get_template_part( 'inc/lib/footer_stylesheets' );
      
      simple_days_customize_fonts_enqueue();

      if ( !is_user_logged_in() ){

      }
    }else{

    }

  }
endif;
add_action( 'wp_footer', 'simple_days_footer_stylesheets' );

if ( ! function_exists( 'highlight_load' ) ) :
  
  function highlight_load() {
    wp_enqueue_style('highlight_style', SIMPLE_DAYS_THEME_URI . 'assets/js/highlight/styles/'.get_theme_mod( 'simple_days_highlight_styles','default').'.css', array(), null);
    wp_enqueue_script('highlight_script',SIMPLE_DAYS_THEME_URI . 'assets/js/highlight/highlight.pack.js', array(), null );
  }
endif;

if ( ! function_exists( 'highlight_onload' ) ) :
  function highlight_onload() {
    echo '<script>hljs.initHighlightingOnLoad();</script>';
  }
endif;

if ( ! function_exists( 'simple_days_add_meta' ) ) :
  function simple_days_add_meta($post_id){

    set_query_var( 'add_meta', $post_id );
    get_template_part( 'inc/lib/add_meta' );
	//var_dump($post_id);

    if ( get_theme_mod( 'simple_days_popular_post' , false)){
      if (!is_singular() || is_user_logged_in()) return;
      if (empty($post_id)) {
        global $post;
        $post_id = $post->ID;
      }
      set_query_var( 'popular_posts', $post_id );
      get_template_part( 'inc/lib/popular_posts' );
    }

  }
endif;
add_action( 'wp_head', 'simple_days_add_meta' );






if ( ! function_exists( 'simple_days_user_profile_enqueue_script' ) ) :
  function simple_days_user_profile_enqueue_script() {
   wp_enqueue_style( 'wp-color-picker');
   wp_enqueue_script( 'wp-color-picker');
 }
endif;

if ( ! function_exists( 'simple_days_user_profile_script' ) ) :
  function simple_days_user_profile_script() {
   echo "<script>
   (function($) {
    $(function() {
      var options = {
        defaultColor: false,
        change: function(event, ui){},
        clear: function() {},
        hide: true,
        palettes: true
      };
      $('.color-picker').wpColorPicker(options);
      });
      })(jQuery);
      </script>".PHP_EOL;
    }
  endif;

  add_action( 'admin_head-profile.php', 'simple_days_user_profile_enqueue_script');
  add_action( 'admin_print_footer_scripts-profile.php', 'simple_days_user_profile_script');

  add_action( 'show_user_profile', 'simple_days_add_user_profile' );
  add_action( 'edit_user_profile', 'simple_days_add_user_profile' );

  if ( ! function_exists( 'simple_days_add_user_profile' ) ) :
  //simple_days_social_user_profile
    function simple_days_add_user_profile( $user ) {

      set_query_var( 'add_user_profile', $user );
      get_template_part( 'inc/lib/add_user_profile' );

    }
  endif;

  add_action( 'personal_options_update', 'simple_days_save_user_profile' );
  add_action( 'edit_user_profile_update', 'simple_days_save_user_profile' );

  if ( ! function_exists( 'simple_days_save_user_profile' ) ) :
    function simple_days_save_user_profile( $user_id ) {

      set_query_var( 'save_user_profile', $user_id );
      get_template_part( 'inc/lib/save_user_profile' );

    }
  endif;





  if ( ! function_exists( 'simple_days_customize_fonts_enqueue' ) ) :
    function simple_days_customize_fonts_enqueue() {

      get_template_part( 'inc/lib/customize_fonts' );

    }
  endif;



  if ( ! function_exists( 'simple_days_comment_author_anchor' ) ) :
    function simple_days_comment_author_anchor( $author_link ){
      return str_replace( "<a", "<a target='_blank'", $author_link );
    }
  endif;
  add_filter( "get_comment_author_link", "simple_days_comment_author_anchor" );



  if ( ! function_exists( 'simple_days_add_quicktags' ) ) :
    function simple_days_add_quicktags() {

      get_template_part( 'inc/lib/add_quicktags' );

    }
  endif;
  add_action( 'admin_print_footer_scripts', 'simple_days_add_quicktags' );

  if ( ! function_exists( 'simple_days_add_editor_styles' ) ) :
    function simple_days_add_editor_styles() {
      
      add_editor_style( 'assets/css/custom-editor-style.css' );

      if ( current_user_can( 'edit_posts' ) && current_user_can( 'edit_pages' ) ) {
        add_filter( 'mce_buttons', 'simple_days_tiny_mce_register_buttons' );
        add_filter( 'mce_external_plugins', 'simple_days_tiny_mce_register_script' );
      }
    }
  endif;
  add_action( 'admin_init', 'simple_days_add_editor_styles' );

  if ( ! function_exists( 'simple_days_tiny_mce_register_script' ) ) :
    function simple_days_tiny_mce_register_script( $plugins ) {
      $plugins['simple_days_alert_plugin'] = SIMPLE_DAYS_THEME_URI . 'assets/js/tinymce/tiny-mce.js';
      return $plugins;
    }
  endif;

  if ( ! function_exists( 'simple_days_tiny_mce_register_buttons' ) ) :
    function simple_days_tiny_mce_register_buttons( $buttons ) {
      $newBtns = array(
        'simpledaysalertlist'
      );
      $buttons = array_merge( $buttons, $newBtns );
      return $buttons;
    }
  endif;










  if ( ! function_exists( 'simple_days_gutenberg_allowed_block_types' ) ) :
    function simple_days_gutenberg_allowed_block_types( $allowed_blocks, $post ) {

      get_template_part( 'inc/gutenberg_block', 'list' );
      $gutenberg_block = get_query_var('gutenberg_block_list');
      $allowed_blocks = array();

      foreach ($gutenberg_block['core_list'] as $key => $value) {
        if(get_theme_mod( 'simple_days_gutenberg_block_'.$key, true))$allowed_blocks[] = 'core/'.$key;
      }
      foreach ($gutenberg_block['embed_list'] as $key => $value) {
        if(get_theme_mod( 'simple_days_gutenberg_block_'.$key, true))$allowed_blocks[] = 'core-embed/'.$key;
      }

      if( $post->post_type === 'page' ) {

      }
      return $allowed_blocks;

    }
//add_filter( 'allowed_block_types', 'simple_days_gutenberg_allowed_block_types', 10, 2 );
  endif;





  if ( ! function_exists( 'simple_days_gutenberg_editor_styles' ) ) :
    
    function simple_days_gutenberg_editor_styles() {
      wp_enqueue_style( 'simple_days_gutenberg_editor_styles', SIMPLE_DAYS_THEME_URI . 'assets/css/gutenberg-editor-style.min.css',array( 'wp-edit-blocks' ) );
      wp_enqueue_style( 'simple_days_gutenberg_front_styles', SIMPLE_DAYS_THEME_URI . 'assets/css/gutenberg-front-one-column-style.min.css',array( 'wp-edit-blocks' ) );
      wp_enqueue_style('font-awesome4', SIMPLE_DAYS_THEME_URI . 'assets/fonts/fontawesome/style.min.css', array(), null);
    }
  endif;
  add_action( 'enqueue_block_editor_assets', 'simple_days_gutenberg_editor_styles' );

  if ( ! function_exists( 'simple_days_gutenberg_front_styles' ) ) :
    function simple_days_gutenberg_front_styles() {
      if(get_theme_mod( 'simple_days_sidebar_layout','3') == '0' || !is_active_sidebar( 'sidebar-1' )){
        wp_enqueue_style( 'simple_days_gutenberg_front_styles', SIMPLE_DAYS_THEME_URI . 'assets/css/gutenberg-front-one-column-style.min.css',array( 'wp-blocks','simple_days_style' ) );
      }else{
        wp_enqueue_style( 'simple_days_gutenberg_front_styles', SIMPLE_DAYS_THEME_URI . 'assets/css/gutenberg-front-style.min.css',array( 'wp-blocks','simple_days_style' ) );
      }
      
      wp_enqueue_script( 'fitvids',SIMPLE_DAYS_THEME_URI . 'assets/js/gutenberg/jquery.fitvids.js', array('jquery'), null, true);
      add_action('wp_footer', 'simple_days_fitvids');
    }
  endif;
  add_action( 'enqueue_block_assets', 'simple_days_gutenberg_front_styles' );

  if ( ! function_exists( 'simple_days_fitvids' ) ) :
    function simple_days_fitvids() {
      echo '<script type="text/javascript">
      jQuery(document).ready(function() {
        jQuery(".wp-block-embed-vimeo").fitVids();
      });</script>';
    }
  endif;


  if (function_exists('register_block_type')) {
    
  }

  if ( ! function_exists( 'simple_days_customizer_css' ) ) :
    
    function simple_days_customizer_css() {

      get_template_part( 'inc/customizer/customizer_css' );

    }
  endif;
  add_action( 'customize_controls_print_styles', 'simple_days_customizer_css' );

  if ( ! function_exists( 'simple_days_customizer_script' ) ) :
    
    function simple_days_customizer_script() {

    }
  endif;
  add_action( 'customize_register', 'simple_days_customizer_script' );

  if ( ! function_exists( 'simple_days_customize_preview' ) ) :
    function simple_days_customize_preview() {

    }
  endif;
  add_action( 'customize_preview_init', 'simple_days_customize_preview' );





  if ( ! function_exists( 'simple_days_admin_enqueue_scripts' ) ) :
    function simple_days_admin_enqueue_scripts() {
      get_template_part( 'inc/lib/admin_enqueue_scripts' );
    }
  endif;
  add_action( 'admin_footer-post-new.php', 'simple_days_admin_enqueue_scripts' );
  add_action( 'admin_footer-post.php', 'simple_days_admin_enqueue_scripts' );

  if ( ! function_exists( 'simple_days_delete_blog_card_cache' ) ) :
    function simple_days_delete_cache() {
      get_template_part( 'inc/lib/delete_cache' );
    }
  endif;
  add_action('switch_theme', 'simple_days_delete_cache');


  if (is_amp){
    get_template_part( 'inc/lib/amp_setup' );
  }


